@@ -1,4 +1,12 @@
 """
+    IRO
+    ===
+
+    Easy and powerful Colorizer for Python!
+
+    Powered by [Yamato Nagata](https://twitter.com/514YJ)
+
+    [GitHub](https://github.com/nagataaaas/Iro)
     Powered by [Yamato Nagata](https://twitter.com/514YJ)
     [GitHub](https://github.com/nagataaaas/Iro)
     :copyright: (c) 2021 by Yamato Nagata.
@@ -10,7 +18,6 @@ import locale
 from .__about__ import __version__
 from .iro import (Iro, Color, Style, ColorRGB, Color256, Font)
 
-
 locale.setlocale(locale.LC_ALL, '')
 
 __all__ = [
@@ -21,4 +28,4 @@ __all__ = [
     "ColorRGB",
     "Color256",
     "Font",
-]
\ No newline at end of file
+]
