@@ -35,7 +35,7 @@ class Iro:
             else:
                 result.append(self.painter(text, open_style))
                 result.append(open_style)
-        result.append(Style._RESET.close())
+        result.append(Style.RESET.close())
 
         return ''.join(result)
 
@@ -93,7 +93,7 @@ class Font:
 
 
 class Style(Enum):
-    _RESET = 0
+    RESET = 0
     BOLD = 1
     DIM = 2
     ITALIC = 3
@@ -103,17 +103,33 @@ class Style(Enum):
     INVERT = 7
     HIDE = 8
     STRIKE = 9
+    OVERLINE = 53
 
     BLACKLETTER_FONT = 20
 
     DOUBLY_UNDERLINE = 21
 
+    OFF_INTENSITY = 22
+    OFF_BOLD = 22
+    OFF_DIM = 22
+    OFF_ITALIC = 23
+    OFF_UNDERLINE = 24
+    OFF_BLINK = 25
+    OFF_INVERT = 27
+    OFF_HIDE = 28
+    OFF_STRIKE = 29
+
+    OFF_COLOR = 39
+    OFF_BG_COLOR = 49
+
+    OFF_OVERLINE = 55
+
     def open(self):
         return '\033[{}m'.format(self.value)
 
     def close(self):
-        val = {0: 0, 1: 22, 2: 22, 3: 23, 4: 24, 5: 25, 6: 25, 7: 27, 8: 28, 9: 29}
-        return '\033[{}m'.format(val[self.value])
+        val = {1: 22, 2: 22, 3: 23, 4: 24, 5: 25, 6: 25, 7: 27, 8: 28, 9: 29, 20: 10, 21: 24, }
+        return '\033[{}m'.format(val.get(self.value, self.value))
 
 
 class Color256:
